@@ -23,7 +23,7 @@
  * SOFTWARE. */
 
 #include "includes.h"
-#include "util.h"
+#include "dbutil.h"
 #include "bignum.h"
 #include "random.h"
 #include "rsa.h"
@@ -45,31 +45,25 @@ rsa_key * gen_rsa_priv_key(unsigned int size) {
 	key = (rsa_key*)m_malloc(sizeof(rsa_key));
 
 	key->e = (mp_int*)m_malloc(sizeof(mp_int));
-	m_mp_init(key->e);
 	key->n = (mp_int*)m_malloc(sizeof(mp_int));
-	m_mp_init(key->n);
 	key->d = (mp_int*)m_malloc(sizeof(mp_int));
-	m_mp_init(key->d);
 	key->p = (mp_int*)m_malloc(sizeof(mp_int));
-	m_mp_init(key->p);
 	key->q = (mp_int*)m_malloc(sizeof(mp_int));
-	m_mp_init(key->q);
+
+	m_mp_init_multi(key->e, key->n, key->d, key->p, key->q,
+			&pminus, &lcm, &qminus, NULL);
 
 	seedrandom();
 
-	m_mp_init(&pminus);
 	if (mp_set_int(key->e, RSA_E) != MP_OKAY) {
 		fprintf(stderr, "rsa generation failed\n");
 		exit(1);
 	}
 
-	m_mp_init(&qminus);
-	m_mp_init(&lcm);
-
 	/* PuTTY doesn't like it if the modulus isn't a multiple of 8 bits,
 	 * so we just generate them until we get one which is OK */
+	getrsaprime(key->p, &pminus, key->e, size/2);
 	do {
-		getrsaprime(key->p, &pminus, key->e, size/2);
 		getrsaprime(key->q, &qminus, key->e, size/2);
 
 		if (mp_mul(key->p, key->q, key->n) != MP_OKAY) {
@@ -85,15 +79,13 @@ rsa_key * gen_rsa_priv_key(unsigned int size) {
 	}
 
 	/* de = 1 mod lcm(p-1,q-1) */
-	/* d = (e^-1) mod lcm(p-1,q-1) */
+	/* therefore d = (e^-1) mod lcm(p-1,q-1) */
 	if (mp_invmod(key->e, &lcm, key->d) != MP_OKAY) {
 		fprintf(stderr, "rsa generation failed\n");
 		exit(1);
 	}
 
-	mp_clear(&pminus);
-	mp_clear(&qminus);
-	mp_clear(&lcm);
+	mp_clear_multi(&pminus, &qminus, &lcm, NULL);
 
 	return key;
 }	
@@ -113,7 +105,6 @@ static void getrsaprime(mp_int* prime, mp_int *primeminus,
 		   the next prime above it */
 		genrandom(buf, size+1);
 		buf[0] |= 0x80; /* MSB set */
-		buf[size] |= 0x01; /* LSB for odd */
 
 		if (mp_read_unsigned_bin(prime, buf, size+1) != MP_OKAY) {
 			fprintf(stderr, "rsa generation failed\n");
@@ -121,7 +112,7 @@ static void getrsaprime(mp_int* prime, mp_int *primeminus,
 		}
 
 		/* find the next integer which is prime, 8 round of miller-rabin */
-		if (mp_prime_next_prime(prime, 8) != MP_OKAY) {
+		if (mp_prime_next_prime(prime, 8, 0) != MP_OKAY) {
 			fprintf(stderr, "rsa generation failed\n");
 			exit(1);
 		}
