@@ -9,7 +9,7 @@
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following condition:
+ * furnished to do so, subject to the following conditions:
  * 
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
@@ -25,8 +25,6 @@
 #ifndef _SERVICE_H_
 #define _SERVICE_H_
 
-#include "options.h"
-
 void recv_msg_service_request();
 
 #endif /* _SERVICE_H_ */
